# Changelog

<!--next-version-placeholder-->

## v1.0.0 (2021-10-30)
### Documentation
* Improves the README file; adds English version ([`5c54d1e`](https://github.com/ivica-k/jmbg-validator/commit/5c54d1eae68a6b34091db846adc3f3ec4367aa9b))
